@@ -185,6 +185,7 @@ Italic     => A non--file buffer.
 \\[helm-buffers-run-multi-occur]\t\tMulti Occur buffer or marked buffers. (C-u toggle force searching current-buffer).
 \\[helm-buffer-switch-other-window]\t\tSwitch other window.
 \\[helm-buffer-switch-other-frame]\t\tSwitch other frame.
+\\[helm-buffers-run-browse-project]\t\tBrowse Project from buffer.
 \\[helm-buffer-run-query-replace-regexp]\t\tQuery replace regexp in marked buffers.
 \\[helm-buffer-run-query-replace]\t\tQuery replace in marked buffers.
 \\[helm-buffer-run-ediff]\t\tEdiff current buffer with candidate.  If two marked buffers ediff those buffers.
@@ -325,12 +326,33 @@ e.g. You can create \"~/new/newnew/newnewnew/my_newfile.txt\".
 - With two prefix args
   same but the cache will be refreshed.
 
-**** You can start a recursive search with Locate of Find (See commands below)
+**** You can start a recursive search with Locate or Find (See commands below)
 
 With Locate you can use a local db with a prefix arg. If the localdb doesn't already
 exists, you will be prompted for its creation, if it exists and you want to refresh it,
 give two prefix args.
 
+Note that when using locate the helm-buffer is empty until you type something,
+but helm use by default the basename of pattern entered in your helm-find-files session,
+hitting M-n should just kick in the locate search with this pattern.
+If you want to automatically do this add the `helm-source-locate'
+to `helm-sources-using-default-as-input'.
+
+**** Recursive completion on subdirectories
+
+Starting from the current directory you are browsing, it is possible
+to have completion of all directories under here.
+So if you are at \"/home/you/foo/\" and you want to go to \"/home/you/foo/bar/baz/somewhere/else\"
+just type \"/home/you/foo/else/\" and hit `C-j', helm will show you all possibles directories
+under \"foo\".
+If you want to prevent auto expansion to kick in while typing \"else\" you can hit either `C-<backspace>'
+or add spaces or 2 dots before \"else\".
+
+NOTE: Completion on subdirectories use locate as backend, you can configure
+the command with `helm-locate-recursive-dirs-command'.
+Because this completion use an index, you may not have all the recent additions
+of directories until you update your index (`updatedb' for locate).
+
 *** Insert filename at point or complete filename at point
 
 On insertion (no completion, i.e nothing at point):
