@@ -586,53 +586,8 @@ Useful in dired buffers when there is inserted subdirs."
 
 ;; Same as `vc-directory-exclusion-list'.
 (defvar helm-walk-ignore-directories
-  '("SCCS" "RCS" "CVS" "MCVS" ".svn" ".git" ".hg" ".bzr"
-    "_MTN" "_darcs" "{arch}" ".gvfs"))
-
-(cl-defun helm-walk-directory (directory &key (path 'basename)
-                                         directories
-                                         match skip-subdirs)
-  "Walk through DIRECTORY tree.
-Argument PATH can be one of basename, relative, full, or a function
-called on file name, default to basename.
-Argument DIRECTORIES when non--nil (default) return also directories names,
-otherwise skip directories names.
-Argument MATCH is a regexp matching files or directories.
-Argument SKIP-SUBDIRS when non--nil will skip `helm-walk-ignore-directories'
-unless it is given as a list of directories, in this case this list will be used
-instead of `helm-walk-ignore-directories'."
-  (let ((fn (cl-case path
-               (basename 'file-name-nondirectory)
-               (relative 'file-relative-name)
-               (full     'identity)
-               (t        path)))) ; A function.
-    (cl-labels ((ls-rec (dir)
-                  (unless (or (and skip-subdirs
-                                   (member (helm-basename dir)
-                                           (if (listp skip-subdirs)
-                                               skip-subdirs
-                                               helm-walk-ignore-directories)))
-                              (file-symlink-p dir))
-                    (cl-loop for f in (sort (file-name-all-completions "" dir)
-                                            'string-lessp)
-                             ;; Use `helm--dir-file-name' to remove the final slash.
-                             ;; Needed to avoid infloop on symlinks symlinking
-                             ;; a directory inside it.
-                             for file = (helm--dir-file-name f dir)
-                             unless (member f '("./" "../"))
-                             ;; A directory.
-                             if (helm--dir-name-p f)
-                             nconc (if directories
-                                       (nconc (and (or (null match)
-                                                       (string-match match f))
-                                                   (list (funcall fn file)))
-                                              (ls-rec file))
-                                       (ls-rec file))
-                             ;; A regular file.
-                             else nconc
-                             (when (or (null match) (string-match match f))
-                               (list (funcall fn file)))))))
-      (ls-rec directory))))
+  '("SCCS/" "RCS/" "CVS/" "MCVS/" ".svn/" ".git/" ".hg/" ".bzr/"
+    "_MTN/" "_darcs/" "{arch}/" ".gvfs/"))
 
 (defsubst helm--dir-file-name (file dir)
   (expand-file-name
@@ -641,6 +596,56 @@ instead of `helm-walk-ignore-directories'."
 (defsubst helm--dir-name-p (str)
   (char-equal (aref str (1- (length str))) ?/))
 
+(cl-defun helm-walk-directory (directory &key (path 'basename)
+                                         directories
+                                         match skip-subdirs)
+  "Walk through DIRECTORY tree.
+
+Argument PATH can be one of basename, relative, full, or a function
+called on file name, default to basename.
+
+Argument DIRECTORIES when non--nil (default) return also directories names,
+otherwise skip directories names, with a value of 'only returns
+only subdirectories, i.e files are skipped.
+
+Argument MATCH is a regexp matching files or directories.
+
+Argument SKIP-SUBDIRS when `t' will skip `helm-walk-ignore-directories'
+otherwise if it is given as a list of directories, this list will be used
+instead of `helm-walk-ignore-directories'."
+  (let ((fn (cl-case path
+               (basename 'file-name-nondirectory)
+               (relative 'file-relative-name)
+               (full     'identity)
+               (t        path)))) ; A function.
+    (setq skip-subdirs (if (listp skip-subdirs)
+                           skip-subdirs
+                           helm-walk-ignore-directories))
+    (cl-labels ((ls-rec (dir)
+                  (unless (file-symlink-p dir)
+                    (cl-loop for f in (sort (file-name-all-completions "" dir)
+                                            'string-lessp)
+                             unless (member f '("./" "../"))
+                             ;; A directory.
+                             ;; Use `helm--dir-file-name' to remove the final slash.
+                             ;; Needed to avoid infloop on directory symlinks.
+                             if (and (helm--dir-name-p f)
+                                     (helm--dir-file-name f dir))
+                             nconc
+                             (unless (member f skip-subdirs)
+                               (if (and directories
+                                        (or (null match)
+                                            (string-match match f)))
+                                   (nconc (list (concat (funcall fn it) "/"))
+                                          (ls-rec it))
+                                   (ls-rec it)))
+                             ;; A regular file.
+                             else nconc
+                             (when (and (null (eq directories 'only))
+                                        (or (null match) (string-match match f)))
+                               (list (funcall fn (expand-file-name f dir))))))))
+      (ls-rec directory))))
+
 (defun helm-file-expand-wildcards (pattern &optional full)
   "Same as `file-expand-wildcards' but allow recursion.
 Recursion happen when PATTERN starts with two stars.
