@@ -1,6 +1,6 @@
 ;;; helm-tags.el --- Helm for Etags. -*- lexical-binding: t -*-
 
-;; Copyright (C) 2012 ~ 2015 Thierry Volpiatto <thierry.volpiatto@gmail.com>
+;; Copyright (C) 2012 ~ 2016 Thierry Volpiatto <thierry.volpiatto@gmail.com>
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -43,12 +43,10 @@ Don't search tag file deeply if outside this value."
   "Allow choosing the tag part of CANDIDATE in `helm-source-etags-select'.
 A tag looks like this:
     filename: \(defun foo
-You can choose matching against only end part of tag (i.e \"foo\"),
-against only the tag part (i.e \"(defun foo\"),
-or against the whole candidate (i.e \"(filename: (defun foo\")."
+You can choose matching against the tag part (i.e \"(defun foo\"),
+or against the whole candidate (i.e \"(filename:5:(defun foo\")."
   :type '(choice
           (const :tag "Match only tag" tag)
-          (const :tag "Match last part of tag" endtag)
           (const :tag "Match all file+tag" all))
   :group 'helm-tags)
 
@@ -161,13 +159,12 @@ If not found in CURRENT-DIR search in upper directory."
 
 (defun helm-etags-create-buffer (file)
   "Create the `helm-buffer' based on contents of etags tag FILE."
-  (let* ((tag-fname file)
-         max
-         (split (with-current-buffer (find-file-noselect tag-fname)
+  (let* (max
+         (split (with-temp-buffer
+                  (insert-file-contents file)
                   (prog1
                       (split-string (buffer-string) "\n" 'omit-nulls)
-                    (setq max (line-number-at-pos (point-max)))
-                    (kill-buffer))))
+                    (setq max (line-number-at-pos (point-max))))))
          (progress-reporter (make-progress-reporter "Loading tag file..." 0 max)))
     (cl-loop
           with fname
@@ -221,11 +218,9 @@ If no entry in cache, create one."
     :match-part (lambda (candidate)
                   ;; Match only the tag part of CANDIDATE
                   ;; and not the filename.
-                  (cl-ecase helm-etags-match-part-only
-                      (endtag (cadr (split-string
-                                     (cl-caddr (helm-grep-split-line candidate)))))
-                      (tag    (cl-caddr (helm-grep-split-line candidate)))
-                      (all    candidate)))
+                  (cl-case helm-etags-match-part-only
+                      (tag (cl-caddr (helm-grep-split-line candidate)))
+                      (t   candidate)))
     :fuzzy-match helm-etags-fuzzy-match
     :help-message 'helm-etags-help-message
     :keymap helm-etags-map
